<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyAgencyRoleRequest;
use App\Http\Requests\StoreAgencyRoleRequest;
use App\Http\Requests\UpdateAgencyRoleRequest;
use App\Models\AgencyRole;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class AgencyRolesController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('agency_role_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $agencyRoles = AgencyRole::all();

        return view('admin.agencyRoles.index', compact('agencyRoles'));
    }

    public function create()
    {
        abort_if(Gate::denies('agency_role_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.agencyRoles.create');
    }

    public function store(StoreAgencyRoleRequest $request)
    {
        $agencyRole = AgencyRole::create($request->all());

        return redirect()->route('admin.agency-roles.index');
    }

    public function edit(AgencyRole $agencyRole)
    {
        abort_if(Gate::denies('agency_role_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.agencyRoles.edit', compact('agencyRole'));
    }

    public function update(UpdateAgencyRoleRequest $request, AgencyRole $agencyRole)
    {
        $agencyRole->update($request->all());

        return redirect()->route('admin.agency-roles.index');
    }

    public function show(AgencyRole $agencyRole)
    {
        abort_if(Gate::denies('agency_role_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.agencyRoles.show', compact('agencyRole'));
    }

    public function destroy(AgencyRole $agencyRole)
    {
        abort_if(Gate::denies('agency_role_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $agencyRole->delete();

        return back();
    }

    public function massDestroy(MassDestroyAgencyRoleRequest $request)
    {
        AgencyRole::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
