<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyDiseaseEmergencyRequest;
use App\Http\Requests\StoreDiseaseEmergencyRequest;
use App\Http\Requests\UpdateDiseaseEmergencyRequest;
use App\Models\DiseaseEmergency;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class DiseaseEmergencyController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('disease_emergency_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $diseaseEmergencies = DiseaseEmergency::all();

        return view('admin.diseaseEmergencies.index', compact('diseaseEmergencies'));
    }

    public function create()
    {
        abort_if(Gate::denies('disease_emergency_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.diseaseEmergencies.create');
    }

    public function store(StoreDiseaseEmergencyRequest $request)
    {
        $diseaseEmergency = DiseaseEmergency::create($request->all());

        return redirect()->route('admin.disease-emergencies.index');
    }

    public function edit(DiseaseEmergency $diseaseEmergency)
    {
        abort_if(Gate::denies('disease_emergency_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.diseaseEmergencies.edit', compact('diseaseEmergency'));
    }

    public function update(UpdateDiseaseEmergencyRequest $request, DiseaseEmergency $diseaseEmergency)
    {
        $diseaseEmergency->update($request->all());

        return redirect()->route('admin.disease-emergencies.index');
    }

    public function show(DiseaseEmergency $diseaseEmergency)
    {
        abort_if(Gate::denies('disease_emergency_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.diseaseEmergencies.show', compact('diseaseEmergency'));
    }

    public function destroy(DiseaseEmergency $diseaseEmergency)
    {
        abort_if(Gate::denies('disease_emergency_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $diseaseEmergency->delete();

        return back();
    }

    public function massDestroy(MassDestroyDiseaseEmergencyRequest $request)
    {
        DiseaseEmergency::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
