<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyExperienceInEpidemiologyRequest;
use App\Http\Requests\StoreExperienceInEpidemiologyRequest;
use App\Http\Requests\UpdateExperienceInEpidemiologyRequest;
use App\Models\ExperienceInEpidemiology;
use App\Models\TrainingLevel;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class ExperienceInEpidemiologyController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('experience_in_epidemiology_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $experienceInEpidemiologies = ExperienceInEpidemiology::with(['rapid_risk_assessments', 'monitoring_system', 'epidemic_survey', 'determination_of_disease_status', 'contact_tracing', 'case_management', 'epidemiological_studies', 'study_protocols', 'data_collection_tools', 'user'])
        ->where('user_id', \Auth::user()->id)
        ->get();

        $training_levels = TrainingLevel::get();

        $users = User::get();

        return view('admin.experienceInEpidemiologies.index', compact('experienceInEpidemiologies', 'training_levels', 'users'));
    }

    public function create()
    {
        abort_if(Gate::denies('experience_in_epidemiology_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rapid_risk_assessments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $monitoring_systems = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $epidemic_surveys = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $determination_of_disease_statuses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $contact_tracings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $case_managements = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $epidemiological_studies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $study_protocols = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $data_collection_tools = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.experienceInEpidemiologies.create', compact('case_managements', 'contact_tracings', 'data_collection_tools', 'determination_of_disease_statuses', 'epidemic_surveys', 'epidemiological_studies', 'monitoring_systems', 'rapid_risk_assessments', 'study_protocols', 'users'));
    }

    public function store(StoreExperienceInEpidemiologyRequest $request)
    {
        $experienceInEpidemiology = ExperienceInEpidemiology::create($request->all());

        return redirect()->route('admin.experience-in-epidemiologies.index');
    }

    public function edit(ExperienceInEpidemiology $experienceInEpidemiology)
    {
        abort_if(Gate::denies('experience_in_epidemiology_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rapid_risk_assessments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $monitoring_systems = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $epidemic_surveys = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $determination_of_disease_statuses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $contact_tracings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $case_managements = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $epidemiological_studies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $study_protocols = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $data_collection_tools = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $experienceInEpidemiology->load('rapid_risk_assessments', 'monitoring_system', 'epidemic_survey', 'determination_of_disease_status', 'contact_tracing', 'case_management', 'epidemiological_studies', 'study_protocols', 'data_collection_tools', 'user');

        return view('admin.experienceInEpidemiologies.edit', compact('case_managements', 'contact_tracings', 'data_collection_tools', 'determination_of_disease_statuses', 'epidemic_surveys', 'epidemiological_studies', 'experienceInEpidemiology', 'monitoring_systems', 'rapid_risk_assessments', 'study_protocols', 'users'));
    }

    public function update(UpdateExperienceInEpidemiologyRequest $request, ExperienceInEpidemiology $experienceInEpidemiology)
    {
        $experienceInEpidemiology->update($request->all());

        return redirect()->route('admin.experience-in-epidemiologies.index');
    }

    public function show(ExperienceInEpidemiology $experienceInEpidemiology)
    {
        abort_if(Gate::denies('experience_in_epidemiology_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $experienceInEpidemiology->load('rapid_risk_assessments', 'monitoring_system', 'epidemic_survey', 'determination_of_disease_status', 'contact_tracing', 'case_management', 'epidemiological_studies', 'study_protocols', 'data_collection_tools', 'user');

        return view('admin.experienceInEpidemiologies.show', compact('experienceInEpidemiology'));
    }

    public function destroy(ExperienceInEpidemiology $experienceInEpidemiology)
    {
        abort_if(Gate::denies('experience_in_epidemiology_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $experienceInEpidemiology->delete();

        return back();
    }

    public function massDestroy(MassDestroyExperienceInEpidemiologyRequest $request)
    {
        ExperienceInEpidemiology::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
