<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyNutritionExperienceRequest;
use App\Http\Requests\StoreNutritionExperienceRequest;
use App\Http\Requests\UpdateNutritionExperienceRequest;
use App\Models\NutritionExperience;
use App\Models\TrainingLevel;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class NutritionExperienceController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('nutrition_experience_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nutritionExperiences = NutritionExperience::with(['assessment_of_the_nutritional_status_of_the_population', 'user'])
        ->where('user_id', \Auth::user()->id)
        ->get();

        $training_levels = TrainingLevel::get();

        $users = User::get();

        return view('admin.nutritionExperiences.index', compact('nutritionExperiences', 'training_levels', 'users'));
    }

    public function create()
    {
        abort_if(Gate::denies('nutrition_experience_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $assessment_of_the_nutritional_status_of_the_populations = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.nutritionExperiences.create', compact('assessment_of_the_nutritional_status_of_the_populations', 'users'));
    }

    public function store(StoreNutritionExperienceRequest $request)
    {
        $nutritionExperience = NutritionExperience::create($request->all());

        return redirect()->route('admin.nutrition-experiences.index');
    }

    public function edit(NutritionExperience $nutritionExperience)
    {
        abort_if(Gate::denies('nutrition_experience_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $assessment_of_the_nutritional_status_of_the_populations = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $nutritionExperience->load('assessment_of_the_nutritional_status_of_the_population', 'user');

        return view('admin.nutritionExperiences.edit', compact('assessment_of_the_nutritional_status_of_the_populations', 'nutritionExperience', 'users'));
    }

    public function update(UpdateNutritionExperienceRequest $request, NutritionExperience $nutritionExperience)
    {
        $nutritionExperience->update($request->all());

        return redirect()->route('admin.nutrition-experiences.index');
    }

    public function show(NutritionExperience $nutritionExperience)
    {
        abort_if(Gate::denies('nutrition_experience_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nutritionExperience->load('assessment_of_the_nutritional_status_of_the_population', 'user');

        return view('admin.nutritionExperiences.show', compact('nutritionExperience'));
    }

    public function destroy(NutritionExperience $nutritionExperience)
    {
        abort_if(Gate::denies('nutrition_experience_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nutritionExperience->delete();

        return back();
    }

    public function massDestroy(MassDestroyNutritionExperienceRequest $request)
    {
        NutritionExperience::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
