<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyPsychosocialExperienceRequest;
use App\Http\Requests\StorePsychosocialExperienceRequest;
use App\Http\Requests\UpdatePsychosocialExperienceRequest;
use App\Models\PsychosocialExperience;
use App\Models\TrainingLevel;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class PsychosocialExperienceController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('psychosocial_experience_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        
        $rolee = \Auth::user()->roles->first();
        
        if($rolee->id == 1)
        {
        $psychosocialExperiences = PsychosocialExperience::with(['psychosocial_experience', 'licensee', 'psychiatrist', 'advisor', 'social_worker', 'trauma_based_therapy', 'cognitive_behavioural_therapy', 'psychodynamic_therapy', 'psychoanalytic_therapy', 'integrative_or_holistic_therapy', 'humanistic_therapy', 'pediatric_therapy', 'user'])
        //->where('user_id', \Auth::user()->id)
        ->get();
        }
        else
        {
            $psychosocialExperiences = PsychosocialExperience::with(['psychosocial_experience', 'licensee', 'psychiatrist', 'advisor', 'social_worker', 'trauma_based_therapy', 'cognitive_behavioural_therapy', 'psychodynamic_therapy', 'psychoanalytic_therapy', 'integrative_or_holistic_therapy', 'humanistic_therapy', 'pediatric_therapy', 'user'])
        ->where('user_id', \Auth::user()->id)
        ->get();
        }

        $training_levels = TrainingLevel::get();

        $users = User::get();

        return view('admin.psychosocialExperiences.index', compact('psychosocialExperiences', 'training_levels', 'users'));
    }

    public function create()
    {
        abort_if(Gate::denies('psychosocial_experience_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $psychosocial_experiences = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $licensees = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $psychiatrists = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $advisors = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $social_workers = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $trauma_based_therapies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $cognitive_behavioural_therapies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $psychodynamic_therapies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $psychoanalytic_therapies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $integrative_or_holistic_therapies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $humanistic_therapies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $pediatric_therapies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.psychosocialExperiences.create', compact('advisors', 'cognitive_behavioural_therapies', 'humanistic_therapies', 'integrative_or_holistic_therapies', 'licensees', 'pediatric_therapies', 'psychiatrists', 'psychoanalytic_therapies', 'psychodynamic_therapies', 'psychosocial_experiences', 'social_workers', 'trauma_based_therapies', 'users'));
    }

    public function store(StorePsychosocialExperienceRequest $request)
    {
        $psychosocialExperience = PsychosocialExperience::create($request->all());

        return redirect()->route('admin.psychosocial-experiences.index');
    }

    public function edit(PsychosocialExperience $psychosocialExperience)
    {
        abort_if(Gate::denies('psychosocial_experience_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $psychosocial_experiences = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $licensees = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $psychiatrists = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $advisors = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $social_workers = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $trauma_based_therapies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $cognitive_behavioural_therapies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $psychodynamic_therapies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $psychoanalytic_therapies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $integrative_or_holistic_therapies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $humanistic_therapies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $pediatric_therapies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $psychosocialExperience->load('psychosocial_experience', 'licensee', 'psychiatrist', 'advisor', 'social_worker', 'trauma_based_therapy', 'cognitive_behavioural_therapy', 'psychodynamic_therapy', 'psychoanalytic_therapy', 'integrative_or_holistic_therapy', 'humanistic_therapy', 'pediatric_therapy', 'user');

        return view('admin.psychosocialExperiences.edit', compact('advisors', 'cognitive_behavioural_therapies', 'humanistic_therapies', 'integrative_or_holistic_therapies', 'licensees', 'pediatric_therapies', 'psychiatrists', 'psychoanalytic_therapies', 'psychodynamic_therapies', 'psychosocialExperience', 'psychosocial_experiences', 'social_workers', 'trauma_based_therapies', 'users'));
    }

    public function update(UpdatePsychosocialExperienceRequest $request, PsychosocialExperience $psychosocialExperience)
    {
        $psychosocialExperience->update($request->all());

        return redirect()->route('admin.psychosocial-experiences.index');
    }

    public function show(PsychosocialExperience $psychosocialExperience)
    {
        abort_if(Gate::denies('psychosocial_experience_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $psychosocialExperience->load('psychosocial_experience', 'licensee', 'psychiatrist', 'advisor', 'social_worker', 'trauma_based_therapy', 'cognitive_behavioural_therapy', 'psychodynamic_therapy', 'psychoanalytic_therapy', 'integrative_or_holistic_therapy', 'humanistic_therapy', 'pediatric_therapy', 'user');

        return view('admin.psychosocialExperiences.show', compact('psychosocialExperience'));
    }

    public function destroy(PsychosocialExperience $psychosocialExperience)
    {
        abort_if(Gate::denies('psychosocial_experience_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $psychosocialExperience->delete();

        return back();
    }

    public function massDestroy(MassDestroyPsychosocialExperienceRequest $request)
    {
        PsychosocialExperience::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
