<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\MassDestroyReadinessAndRtMemberRequest;
use App\Http\Requests\StoreReadinessAndRtMemberRequest;
use App\Http\Requests\UpdateReadinessAndRtMemberRequest;
use App\Models\ReadinessAndRtMember;
use App\Models\RrtTraining;
use App\Models\User;
use App\Models\Vaccinationation;
use Gate;
use Illuminate\Http\Request;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use Symfony\Component\HttpFoundation\Response;

class ReadinessAndRtMembersController extends Controller
{
    use MediaUploadingTrait;

    public function index()
    {
        abort_if(Gate::denies('readiness_and_rt_member_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $readinessAndRtMembers = ReadinessAndRtMember::with(['user', 'vaccinations', 'training_1', 'training_2', 'trainings_3', 'training_4', 'media'])->get();

        $users = User::get();

        $vaccinationations = Vaccinationation::get();

        $rrt_trainings = RrtTraining::get();

        return view('admin.readinessAndRtMembers.index', compact('readinessAndRtMembers', 'rrt_trainings', 'users', 'vaccinationations'));
    }

    public function create()
    {
        abort_if(Gate::denies('readiness_and_rt_member_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $vaccinations = Vaccinationation::pluck('name', 'id');

        $training_1s = RrtTraining::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $training_2s = RrtTraining::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $trainings_3s = RrtTraining::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $training_4s = RrtTraining::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.readinessAndRtMembers.create', compact('training_1s', 'training_2s', 'training_4s', 'trainings_3s', 'users', 'vaccinations'));
    }

    public function store(StoreReadinessAndRtMemberRequest $request)
    {
        $readinessAndRtMember = ReadinessAndRtMember::create($request->all());
        $readinessAndRtMember->vaccinations()->sync($request->input('vaccinations', []));
        foreach ($request->input('upload_certified_rrt_training', []) as $file) {
            $readinessAndRtMember->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('upload_certified_rrt_training');
        }

        foreach ($request->input('upload_medical_certificate', []) as $file) {
            $readinessAndRtMember->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('upload_medical_certificate');
        }

        foreach ($request->input('upload_certificate_of_physical_fitness', []) as $file) {
            $readinessAndRtMember->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('upload_certificate_of_physical_fitness');
        }

        foreach ($request->input('training_support_documents', []) as $file) {
            $readinessAndRtMember->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('training_support_documents');
        }

        if ($media = $request->input('ck-media', false)) {
            Media::whereIn('id', $media)->update(['model_id' => $readinessAndRtMember->id]);
        }

        return redirect()->route('admin.readiness-and-rt-members.index');
    }

    public function edit(ReadinessAndRtMember $readinessAndRtMember)
    {
        abort_if(Gate::denies('readiness_and_rt_member_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $vaccinations = Vaccinationation::pluck('name', 'id');

        $training_1s = RrtTraining::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $training_2s = RrtTraining::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $trainings_3s = RrtTraining::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $training_4s = RrtTraining::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $readinessAndRtMember->load('user', 'vaccinations', 'training_1', 'training_2', 'trainings_3', 'training_4');

        return view('admin.readinessAndRtMembers.edit', compact('readinessAndRtMember', 'training_1s', 'training_2s', 'training_4s', 'trainings_3s', 'users', 'vaccinations'));
    }

    public function update(UpdateReadinessAndRtMemberRequest $request, ReadinessAndRtMember $readinessAndRtMember)
    {
        $readinessAndRtMember->update($request->all());
        $readinessAndRtMember->vaccinations()->sync($request->input('vaccinations', []));
        if (count($readinessAndRtMember->upload_certified_rrt_training) > 0) {
            foreach ($readinessAndRtMember->upload_certified_rrt_training as $media) {
                if (!in_array($media->file_name, $request->input('upload_certified_rrt_training', []))) {
                    $media->delete();
                }
            }
        }
        $media = $readinessAndRtMember->upload_certified_rrt_training->pluck('file_name')->toArray();
        foreach ($request->input('upload_certified_rrt_training', []) as $file) {
            if (count($media) === 0 || !in_array($file, $media)) {
                $readinessAndRtMember->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('upload_certified_rrt_training');
            }
        }

        if (count($readinessAndRtMember->upload_medical_certificate) > 0) {
            foreach ($readinessAndRtMember->upload_medical_certificate as $media) {
                if (!in_array($media->file_name, $request->input('upload_medical_certificate', []))) {
                    $media->delete();
                }
            }
        }
        $media = $readinessAndRtMember->upload_medical_certificate->pluck('file_name')->toArray();
        foreach ($request->input('upload_medical_certificate', []) as $file) {
            if (count($media) === 0 || !in_array($file, $media)) {
                $readinessAndRtMember->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('upload_medical_certificate');
            }
        }

        if (count($readinessAndRtMember->upload_certificate_of_physical_fitness) > 0) {
            foreach ($readinessAndRtMember->upload_certificate_of_physical_fitness as $media) {
                if (!in_array($media->file_name, $request->input('upload_certificate_of_physical_fitness', []))) {
                    $media->delete();
                }
            }
        }
        $media = $readinessAndRtMember->upload_certificate_of_physical_fitness->pluck('file_name')->toArray();
        foreach ($request->input('upload_certificate_of_physical_fitness', []) as $file) {
            if (count($media) === 0 || !in_array($file, $media)) {
                $readinessAndRtMember->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('upload_certificate_of_physical_fitness');
            }
        }

        if (count($readinessAndRtMember->training_support_documents) > 0) {
            foreach ($readinessAndRtMember->training_support_documents as $media) {
                if (!in_array($media->file_name, $request->input('training_support_documents', []))) {
                    $media->delete();
                }
            }
        }
        $media = $readinessAndRtMember->training_support_documents->pluck('file_name')->toArray();
        foreach ($request->input('training_support_documents', []) as $file) {
            if (count($media) === 0 || !in_array($file, $media)) {
                $readinessAndRtMember->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('training_support_documents');
            }
        }

        return redirect()->route('admin.readiness-and-rt-members.index');
    }

    public function show(ReadinessAndRtMember $readinessAndRtMember)
    {
        abort_if(Gate::denies('readiness_and_rt_member_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $readinessAndRtMember->load('user', 'vaccinations', 'training_1', 'training_2', 'trainings_3', 'training_4');

        return view('admin.readinessAndRtMembers.show', compact('readinessAndRtMember'));
    }

    public function destroy(ReadinessAndRtMember $readinessAndRtMember)
    {
        abort_if(Gate::denies('readiness_and_rt_member_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $readinessAndRtMember->delete();

        return back();
    }

    public function massDestroy(MassDestroyReadinessAndRtMemberRequest $request)
    {
        ReadinessAndRtMember::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function storeCKEditorImages(Request $request)
    {
        abort_if(Gate::denies('readiness_and_rt_member_create') && Gate::denies('readiness_and_rt_member_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $model         = new ReadinessAndRtMember();
        $model->id     = $request->input('crud_id', 0);
        $model->exists = true;
        $media         = $model->addMediaFromRequest('upload')->toMediaCollection('ck-media');

        return response()->json(['id' => $media->id, 'url' => $media->getUrl()], Response::HTTP_CREATED);
    }
}
