<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyRelevantTrainingRequest;
use App\Http\Requests\StoreRelevantTrainingRequest;
use App\Http\Requests\UpdateRelevantTrainingRequest;
use App\Models\RelevantTraining;
use App\Models\TrainingLevel;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class RelevantTrainingController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('relevant_training_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $user_id = \Auth::user()->id;

        $rolee = \Auth::user()->roles->first();
        
        if($rolee->id == 1)
        {
 
        $relevantTrainings = RelevantTraining::with(['experience_in_crec', 'strategic_communications_planning', 'media_environments', 'content_of_media_communications', 'graphic_design', 'social_media_web_content', 'communications_field_deployment', 'audience_analysis_strategies', 'community_engagement', 'specialist_in_health_educ_ches_or_a_certificate_of_master', 'health_education_communication_programme', 'participation_in_crisis_and_emergency_risk_communication', 'crisis_and_emergency_risk_communication_cerc_trainer', 'political_experiences', 'content_of_the_intervener_hearing', 'stakeholder_organization', 'responsibility_for_response_risk', 'decision_memos', 'user'])
        //->where('user_id', $user_id)
        ->get();
        }
        else
        {
            $relevantTrainings = RelevantTraining::with(['experience_in_crec', 'strategic_communications_planning', 'media_environments', 'content_of_media_communications', 'graphic_design', 'social_media_web_content', 'communications_field_deployment', 'audience_analysis_strategies', 'community_engagement', 'specialist_in_health_educ_ches_or_a_certificate_of_master', 'health_education_communication_programme', 'participation_in_crisis_and_emergency_risk_communication', 'crisis_and_emergency_risk_communication_cerc_trainer', 'political_experiences', 'content_of_the_intervener_hearing', 'stakeholder_organization', 'responsibility_for_response_risk', 'decision_memos', 'user'])
            ->where('user_id', $user_id)
            ->get();
        }

        $training_levels = TrainingLevel::get();

        $users = User::get();

        return view('admin.relevantTrainings.index', compact('relevantTrainings', 'training_levels', 'users'));
    }

    public function create()
    {
        abort_if(Gate::denies('relevant_training_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $experience_in_crecs = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $strategic_communications_plannings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $media_environments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $content_of_media_communications = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $graphic_designs = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $social_media_web_contents = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $communications_field_deployments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $audience_analysis_strategies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $community_engagements = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $specialist_in_health_educ_ches_or_a_certificate_of_masters = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $health_education_communication_programmes = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $participation_in_crisis_and_emergency_risk_communications = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $crisis_and_emergency_risk_communication_cerc_trainers = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $political_experiences = TrainingLevel::pluck('name', 'id');

        $content_of_the_intervener_hearings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $stakeholder_organizations = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $responsibility_for_response_risks = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $decision_memos = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.relevantTrainings.create', compact('audience_analysis_strategies', 'communications_field_deployments', 'community_engagements', 'content_of_media_communications', 'content_of_the_intervener_hearings', 'crisis_and_emergency_risk_communication_cerc_trainers', 'decision_memos', 'experience_in_crecs', 'graphic_designs', 'health_education_communication_programmes', 'media_environments', 'participation_in_crisis_and_emergency_risk_communications', 'political_experiences', 'responsibility_for_response_risks', 'social_media_web_contents', 'specialist_in_health_educ_ches_or_a_certificate_of_masters', 'stakeholder_organizations', 'strategic_communications_plannings', 'users'));
    }

    public function store(StoreRelevantTrainingRequest $request)
    {
        $relevantTraining = RelevantTraining::create($request->all());
        $relevantTraining->political_experiences()->sync($request->input('political_experiences', []));

        return redirect()->route('admin.relevant-trainings.index');
    }

    public function edit(RelevantTraining $relevantTraining)
    {
        abort_if(Gate::denies('relevant_training_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $experience_in_crecs = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $strategic_communications_plannings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $media_environments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $content_of_media_communications = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $graphic_designs = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $social_media_web_contents = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $communications_field_deployments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $audience_analysis_strategies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $community_engagements = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $specialist_in_health_educ_ches_or_a_certificate_of_masters = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $health_education_communication_programmes = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $participation_in_crisis_and_emergency_risk_communications = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $crisis_and_emergency_risk_communication_cerc_trainers = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $political_experiences = TrainingLevel::pluck('name', 'id');

        $content_of_the_intervener_hearings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $stakeholder_organizations = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $responsibility_for_response_risks = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $decision_memos = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $relevantTraining->load('experience_in_crec', 'strategic_communications_planning', 'media_environments', 'content_of_media_communications', 'graphic_design', 'social_media_web_content', 'communications_field_deployment', 'audience_analysis_strategies', 'community_engagement', 'specialist_in_health_educ_ches_or_a_certificate_of_master', 'health_education_communication_programme', 'participation_in_crisis_and_emergency_risk_communication', 'crisis_and_emergency_risk_communication_cerc_trainer', 'political_experiences', 'content_of_the_intervener_hearing', 'stakeholder_organization', 'responsibility_for_response_risk', 'decision_memos', 'user');

        return view('admin.relevantTrainings.edit', compact('audience_analysis_strategies', 'communications_field_deployments', 'community_engagements', 'content_of_media_communications', 'content_of_the_intervener_hearings', 'crisis_and_emergency_risk_communication_cerc_trainers', 'decision_memos', 'experience_in_crecs', 'graphic_designs', 'health_education_communication_programmes', 'media_environments', 'participation_in_crisis_and_emergency_risk_communications', 'political_experiences', 'relevantTraining', 'responsibility_for_response_risks', 'social_media_web_contents', 'specialist_in_health_educ_ches_or_a_certificate_of_masters', 'stakeholder_organizations', 'strategic_communications_plannings', 'users'));
    }

    public function update(UpdateRelevantTrainingRequest $request, RelevantTraining $relevantTraining)
    {
        $relevantTraining->update($request->all());
        $relevantTraining->political_experiences()->sync($request->input('political_experiences', []));

        return redirect()->route('admin.relevant-trainings.index');
    }

    public function show(RelevantTraining $relevantTraining)
    {
        abort_if(Gate::denies('relevant_training_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $relevantTraining->load('experience_in_crec', 'strategic_communications_planning', 'media_environments', 'content_of_media_communications', 'graphic_design', 'social_media_web_content', 'communications_field_deployment', 'audience_analysis_strategies', 'community_engagement', 'specialist_in_health_educ_ches_or_a_certificate_of_master', 'health_education_communication_programme', 'participation_in_crisis_and_emergency_risk_communication', 'crisis_and_emergency_risk_communication_cerc_trainer', 'political_experiences', 'content_of_the_intervener_hearing', 'stakeholder_organization', 'responsibility_for_response_risk', 'decision_memos', 'user');

        return view('admin.relevantTrainings.show', compact('relevantTraining'));
    }

    public function destroy(RelevantTraining $relevantTraining)
    {
        abort_if(Gate::denies('relevant_training_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $relevantTraining->delete();

        return back();
    }

    public function massDestroy(MassDestroyRelevantTrainingRequest $request)
    {
        RelevantTraining::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
