<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyRrtTrainingRequest;
use App\Http\Requests\StoreRrtTrainingRequest;
use App\Http\Requests\UpdateRrtTrainingRequest;
use App\Models\RrtTraining;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class RrtTrainingsController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('rrt_training_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rrtTrainings = RrtTraining::all();

        return view('admin.rrtTrainings.index', compact('rrtTrainings'));
    }

    public function create()
    {
        abort_if(Gate::denies('rrt_training_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.rrtTrainings.create');
    }

    public function store(StoreRrtTrainingRequest $request)
    {
        $rrtTraining = RrtTraining::create($request->all());

        return redirect()->route('admin.rrt-trainings.index');
    }

    public function edit(RrtTraining $rrtTraining)
    {
        abort_if(Gate::denies('rrt_training_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.rrtTrainings.edit', compact('rrtTraining'));
    }

    public function update(UpdateRrtTrainingRequest $request, RrtTraining $rrtTraining)
    {
        $rrtTraining->update($request->all());

        return redirect()->route('admin.rrt-trainings.index');
    }

    public function show(RrtTraining $rrtTraining)
    {
        abort_if(Gate::denies('rrt_training_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.rrtTrainings.show', compact('rrtTraining'));
    }

    public function destroy(RrtTraining $rrtTraining)
    {
        abort_if(Gate::denies('rrt_training_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rrtTraining->delete();

        return back();
    }

    public function massDestroy(MassDestroyRrtTrainingRequest $request)
    {
        RrtTraining::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
