<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroySecurityManagerExperienceRequest;
use App\Http\Requests\StoreSecurityManagerExperienceRequest;
use App\Http\Requests\UpdateSecurityManagerExperienceRequest;
use App\Models\Month;
use App\Models\SecurityManagerExperience;
use App\Models\TrainingLevel;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class SecurityManagerExperienceController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('security_manager_experience_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $securityManagerExperiences = SecurityManagerExperience::with(['occupational_health_and_safety_assessment', 'osh_y_n_facility_assessment', 'development_of_an_incident_action', 'other_training_on_osh', 'training_received_in_the_field_of_expertise', 'if_not_please_indicate_the_months'])->get();

        $training_levels = TrainingLevel::get();

        $months = Month::get();

        return view('admin.securityManagerExperiences.index', compact('months', 'securityManagerExperiences', 'training_levels'));
    }

    public function create()
    {
        abort_if(Gate::denies('security_manager_experience_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $occupational_health_and_safety_assessments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $osh_y_n_facility_assessments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $development_of_an_incident_actions = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $other_training_on_oshes = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $training_received_in_the_field_of_expertises = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $if_not_please_indicate_the_months = Month::pluck('name', 'id');

        return view('admin.securityManagerExperiences.create', compact('development_of_an_incident_actions', 'if_not_please_indicate_the_months', 'occupational_health_and_safety_assessments', 'osh_y_n_facility_assessments', 'other_training_on_oshes', 'training_received_in_the_field_of_expertises'));
    }

    public function store(StoreSecurityManagerExperienceRequest $request)
    {
        $securityManagerExperience = SecurityManagerExperience::create($request->all());
        $securityManagerExperience->if_not_please_indicate_the_months()->sync($request->input('if_not_please_indicate_the_months', []));

        return redirect()->route('admin.security-manager-experiences.index');
    }

    public function edit(SecurityManagerExperience $securityManagerExperience)
    {
        abort_if(Gate::denies('security_manager_experience_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $occupational_health_and_safety_assessments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $osh_y_n_facility_assessments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $development_of_an_incident_actions = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $other_training_on_oshes = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $training_received_in_the_field_of_expertises = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $if_not_please_indicate_the_months = Month::pluck('name', 'id');

        $securityManagerExperience->load('occupational_health_and_safety_assessment', 'osh_y_n_facility_assessment', 'development_of_an_incident_action', 'other_training_on_osh', 'training_received_in_the_field_of_expertise', 'if_not_please_indicate_the_months');

        return view('admin.securityManagerExperiences.edit', compact('development_of_an_incident_actions', 'if_not_please_indicate_the_months', 'occupational_health_and_safety_assessments', 'osh_y_n_facility_assessments', 'other_training_on_oshes', 'securityManagerExperience', 'training_received_in_the_field_of_expertises'));
    }

    public function update(UpdateSecurityManagerExperienceRequest $request, SecurityManagerExperience $securityManagerExperience)
    {
        $securityManagerExperience->update($request->all());
        $securityManagerExperience->if_not_please_indicate_the_months()->sync($request->input('if_not_please_indicate_the_months', []));

        return redirect()->route('admin.security-manager-experiences.index');
    }

    public function show(SecurityManagerExperience $securityManagerExperience)
    {
        abort_if(Gate::denies('security_manager_experience_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $securityManagerExperience->load('occupational_health_and_safety_assessment', 'osh_y_n_facility_assessment', 'development_of_an_incident_action', 'other_training_on_osh', 'training_received_in_the_field_of_expertise', 'if_not_please_indicate_the_months');

        return view('admin.securityManagerExperiences.show', compact('securityManagerExperience'));
    }

    public function destroy(SecurityManagerExperience $securityManagerExperience)
    {
        abort_if(Gate::denies('security_manager_experience_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $securityManagerExperience->delete();

        return back();
    }

    public function massDestroy(MassDestroySecurityManagerExperienceRequest $request)
    {
        SecurityManagerExperience::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
