<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyTrainingLevelRequest;
use App\Http\Requests\StoreTrainingLevelRequest;
use App\Http\Requests\UpdateTrainingLevelRequest;
use App\Models\TrainingLevel;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class TrainingLevelsController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('training_level_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $trainingLevels = TrainingLevel::all();

        return view('admin.trainingLevels.index', compact('trainingLevels'));
    }

    public function create()
    {
        abort_if(Gate::denies('training_level_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.trainingLevels.create');
    }

    public function store(StoreTrainingLevelRequest $request)
    {
        $trainingLevel = TrainingLevel::create($request->all());

        return redirect()->route('admin.training-levels.index');
    }

    public function edit(TrainingLevel $trainingLevel)
    {
        abort_if(Gate::denies('training_level_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.trainingLevels.edit', compact('trainingLevel'));
    }

    public function update(UpdateTrainingLevelRequest $request, TrainingLevel $trainingLevel)
    {
        $trainingLevel->update($request->all());

        return redirect()->route('admin.training-levels.index');
    }

    public function show(TrainingLevel $trainingLevel)
    {
        abort_if(Gate::denies('training_level_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.trainingLevels.show', compact('trainingLevel'));
    }

    public function destroy(TrainingLevel $trainingLevel)
    {
        abort_if(Gate::denies('training_level_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $trainingLevel->delete();

        return back();
    }

    public function massDestroy(MassDestroyTrainingLevelRequest $request)
    {
        TrainingLevel::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
