<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyWaterSanitationHygieneWashRequest;
use App\Http\Requests\StoreWaterSanitationHygieneWashRequest;
use App\Http\Requests\UpdateWaterSanitationHygieneWashRequest;
use App\Models\TrainingLevel;
use App\Models\WaterSanitationHygieneWash;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class WaterSanitationHygieneWashController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('water_sanitation_hygiene_wash_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $waterSanitationHygieneWashes = WaterSanitationHygieneWash::with(['in_healthcare_settings', 'in_a_non_medical', 'source_water_assessment', 'water_analysis', 'train_others_on_water_testing_and_aquatab', 'water_infrastructure_mapping'])->get();

        $training_levels = TrainingLevel::get();

        return view('admin.waterSanitationHygieneWashes.index', compact('training_levels', 'waterSanitationHygieneWashes'));
    }

    public function create()
    {
        abort_if(Gate::denies('water_sanitation_hygiene_wash_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $in_healthcare_settings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $in_a_non_medicals = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $source_water_assessments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $water_analyses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $train_others_on_water_testing_and_aquatabs = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $water_infrastructure_mappings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.waterSanitationHygieneWashes.create', compact('in_a_non_medicals', 'in_healthcare_settings', 'source_water_assessments', 'train_others_on_water_testing_and_aquatabs', 'water_analyses', 'water_infrastructure_mappings'));
    }

    public function store(StoreWaterSanitationHygieneWashRequest $request)
    {
        $waterSanitationHygieneWash = WaterSanitationHygieneWash::create($request->all());

        return redirect()->route('admin.water-sanitation-hygiene-washes.index');
    }

    public function edit(WaterSanitationHygieneWash $waterSanitationHygieneWash)
    {
        abort_if(Gate::denies('water_sanitation_hygiene_wash_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $in_healthcare_settings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $in_a_non_medicals = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $source_water_assessments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $water_analyses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $train_others_on_water_testing_and_aquatabs = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $water_infrastructure_mappings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $waterSanitationHygieneWash->load('in_healthcare_settings', 'in_a_non_medical', 'source_water_assessment', 'water_analysis', 'train_others_on_water_testing_and_aquatab', 'water_infrastructure_mapping');

        return view('admin.waterSanitationHygieneWashes.edit', compact('in_a_non_medicals', 'in_healthcare_settings', 'source_water_assessments', 'train_others_on_water_testing_and_aquatabs', 'waterSanitationHygieneWash', 'water_analyses', 'water_infrastructure_mappings'));
    }

    public function update(UpdateWaterSanitationHygieneWashRequest $request, WaterSanitationHygieneWash $waterSanitationHygieneWash)
    {
        $waterSanitationHygieneWash->update($request->all());

        return redirect()->route('admin.water-sanitation-hygiene-washes.index');
    }

    public function show(WaterSanitationHygieneWash $waterSanitationHygieneWash)
    {
        abort_if(Gate::denies('water_sanitation_hygiene_wash_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $waterSanitationHygieneWash->load('in_healthcare_settings', 'in_a_non_medical', 'source_water_assessment', 'water_analysis', 'train_others_on_water_testing_and_aquatab', 'water_infrastructure_mapping');

        return view('admin.waterSanitationHygieneWashes.show', compact('waterSanitationHygieneWash'));
    }

    public function destroy(WaterSanitationHygieneWash $waterSanitationHygieneWash)
    {
        abort_if(Gate::denies('water_sanitation_hygiene_wash_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $waterSanitationHygieneWash->delete();

        return back();
    }

    public function massDestroy(MassDestroyWaterSanitationHygieneWashRequest $request)
    {
        WaterSanitationHygieneWash::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
