<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreHazardousMaterialsExperienceRequest;
use App\Http\Requests\UpdateHazardousMaterialsExperienceRequest;
use App\Http\Resources\Admin\HazardousMaterialsExperienceResource;
use App\Models\HazardousMaterialsExperience;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class HazardousMaterialsExperienceApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('hazardous_materials_experience_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new HazardousMaterialsExperienceResource(HazardousMaterialsExperience::with(['certified_hazardous_materials_manager_chmm', 'certified_industrial_hygienist_cih', 'hazmat_specialist_training', 'record_keeping', 'hazardous_materials_management_y_n_program', 'medical_waste_plans', 'spill_response_plans', 'hazardous_waste_reduction_plans', 'hazardous_waste_contingency_plans', 'stormwater_y_n_plans', 'occupational_health_and_safety_y_n_programs', 'radiation_protection_plan', 'collection_segregation_and_transport_of_hazardous_waste', 'training_others_on_hazardous_waste'])->get());
    }

    public function store(StoreHazardousMaterialsExperienceRequest $request)
    {
        $hazardousMaterialsExperience = HazardousMaterialsExperience::create($request->all());

        return (new HazardousMaterialsExperienceResource($hazardousMaterialsExperience))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(HazardousMaterialsExperience $hazardousMaterialsExperience)
    {
        abort_if(Gate::denies('hazardous_materials_experience_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new HazardousMaterialsExperienceResource($hazardousMaterialsExperience->load(['certified_hazardous_materials_manager_chmm', 'certified_industrial_hygienist_cih', 'hazmat_specialist_training', 'record_keeping', 'hazardous_materials_management_y_n_program', 'medical_waste_plans', 'spill_response_plans', 'hazardous_waste_reduction_plans', 'hazardous_waste_contingency_plans', 'stormwater_y_n_plans', 'occupational_health_and_safety_y_n_programs', 'radiation_protection_plan', 'collection_segregation_and_transport_of_hazardous_waste', 'training_others_on_hazardous_waste']));
    }

    public function update(UpdateHazardousMaterialsExperienceRequest $request, HazardousMaterialsExperience $hazardousMaterialsExperience)
    {
        $hazardousMaterialsExperience->update($request->all());

        return (new HazardousMaterialsExperienceResource($hazardousMaterialsExperience))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(HazardousMaterialsExperience $hazardousMaterialsExperience)
    {
        abort_if(Gate::denies('hazardous_materials_experience_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $hazardousMaterialsExperience->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
