<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreInfectionPreventControlRequest;
use App\Http\Requests\UpdateInfectionPreventControlRequest;
use App\Http\Resources\Admin\InfectionPreventControlResource;
use App\Models\InfectionPreventControl;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class InfectionPreventControlApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('infection_prevent_control_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new InfectionPreventControlResource(InfectionPreventControl::with(['in_healthcare_settings', 'in_a_non_medical', 'outbreak_investigations', 'facility_assessments', 'developing_infection_prevention', 'infection_prevention_and_control', 'quality_improvement', 'ppe', 'point_of_entry_border_health', 'poc_non_border', 'rsi'])->get());
    }

    public function store(StoreInfectionPreventControlRequest $request)
    {
        $infectionPreventControl = InfectionPreventControl::create($request->all());

        return (new InfectionPreventControlResource($infectionPreventControl))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(InfectionPreventControl $infectionPreventControl)
    {
        abort_if(Gate::denies('infection_prevent_control_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new InfectionPreventControlResource($infectionPreventControl->load(['in_healthcare_settings', 'in_a_non_medical', 'outbreak_investigations', 'facility_assessments', 'developing_infection_prevention', 'infection_prevention_and_control', 'quality_improvement', 'ppe', 'point_of_entry_border_health', 'poc_non_border', 'rsi']));
    }

    public function update(UpdateInfectionPreventControlRequest $request, InfectionPreventControl $infectionPreventControl)
    {
        $infectionPreventControl->update($request->all());

        return (new InfectionPreventControlResource($infectionPreventControl))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(InfectionPreventControl $infectionPreventControl)
    {
        abort_if(Gate::denies('infection_prevent_control_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $infectionPreventControl->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
