<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreRequesterRequest;
use App\Http\Requests\UpdateRequesterRequest;
use App\Http\Resources\Admin\RequesterResource;
use App\Models\Requester;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class RequesterApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('requester_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new RequesterResource(Requester::all());
    }

    public function store(StoreRequesterRequest $request)
    {
        $requester = Requester::create($request->all());

        return (new RequesterResource($requester))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(Requester $requester)
    {
        abort_if(Gate::denies('requester_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new RequesterResource($requester);
    }

    public function update(UpdateRequesterRequest $request, Requester $requester)
    {
        $requester->update($request->all());

        return (new RequesterResource($requester))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(Requester $requester)
    {
        abort_if(Gate::denies('requester_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $requester->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
