<?php

namespace App\Models;

use \DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class EmergencyResponse extends Model
{
    use SoftDeletes;
    use HasFactory;

    public $table = 'emergency_responses';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'domestic_emergency_response_id',
        'cross_sectoral_id',
        'response_to_international_emergencies_id',
        'eoc_ims_id',
        'vaccination_campaigns_id',
        'emergency_leadership_role_id',
        'multi_sectoral_emergency_response_plans_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function domestic_emergency_response()
    {
        return $this->belongsTo(TrainingLevel::class, 'domestic_emergency_response_id');
    }

    public function cross_sectoral()
    {
        return $this->belongsTo(TrainingLevel::class, 'cross_sectoral_id');
    }

    public function response_to_international_emergencies()
    {
        return $this->belongsTo(TrainingLevel::class, 'response_to_international_emergencies_id');
    }

    public function eoc_ims()
    {
        return $this->belongsTo(TrainingLevel::class, 'eoc_ims_id');
    }

    public function vaccination_campaigns()
    {
        return $this->belongsTo(TrainingLevel::class, 'vaccination_campaigns_id');
    }

    public function emergency_leadership_role()
    {
        return $this->belongsTo(TrainingLevel::class, 'emergency_leadership_role_id');
    }

    public function multi_sectoral_emergency_response_plans()
    {
        return $this->belongsTo(TrainingLevel::class, 'multi_sectoral_emergency_response_plans_id');
    }

    public function emergency_diseases()
    {
        return $this->belongsToMany(DiseaseEmergency::class);
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
