<?php

namespace App\Models;

use \DateTimeInterface;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;
use Spatie\MediaLibrary\MediaCollections\Models\Media;

class ReadinessAndRtMember extends Model implements HasMedia
{
    use SoftDeletes;
    use InteractsWithMedia;
    use HasFactory;

    public $table = 'readiness_and_rt_members';

    protected $appends = [
        'upload_certified_rrt_training',
        'upload_medical_certificate',
        'upload_certificate_of_physical_fitness',
        'training_support_documents',
    ];

    protected $dates = [
        'training_1_date',
        'training_1_expiration_date',
        'training_2_date',
        'training_2_expiration_date',
        'training_3_date',
        'training_3_expiration_date',
        'training_4_date',
        'training_4_expiration_date',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'user_id',
        'training_1_id',
        'training_1_date',
        'training_1_expiration_date',
        'training_2_id',
        'training_2_date',
        'training_2_expiration_date',
        'training_3_date',
        'trainings_3_id',
        'training_3_expiration_date',
        'training_4_id',
        'training_4_date',
        'training_4_expiration_date',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function registerMediaConversions(Media $media = null): void
    {
        $this->addMediaConversion('thumb')->fit('crop', 50, 50);
        $this->addMediaConversion('preview')->fit('crop', 120, 120);
    }

    public function getUploadCertifiedRrtTrainingAttribute()
    {
        return $this->getMedia('upload_certified_rrt_training');
    }

    public function getUploadMedicalCertificateAttribute()
    {
        return $this->getMedia('upload_medical_certificate');
    }

    public function getUploadCertificateOfPhysicalFitnessAttribute()
    {
        return $this->getMedia('upload_certificate_of_physical_fitness');
    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    public function vaccinations()
    {
        return $this->belongsToMany(Vaccinationation::class);
    }

    public function training_1()
    {
        return $this->belongsTo(RrtTraining::class, 'training_1_id');
    }

    public function getTraining1DateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setTraining1DateAttribute($value)
    {
        $this->attributes['training_1_date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function getTraining1ExpirationDateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setTraining1ExpirationDateAttribute($value)
    {
        $this->attributes['training_1_expiration_date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function training_2()
    {
        return $this->belongsTo(RrtTraining::class, 'training_2_id');
    }

    public function getTraining2DateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setTraining2DateAttribute($value)
    {
        $this->attributes['training_2_date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function getTraining2ExpirationDateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setTraining2ExpirationDateAttribute($value)
    {
        $this->attributes['training_2_expiration_date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function getTraining3DateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setTraining3DateAttribute($value)
    {
        $this->attributes['training_3_date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function trainings_3()
    {
        return $this->belongsTo(RrtTraining::class, 'trainings_3_id');
    }

    public function getTraining3ExpirationDateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setTraining3ExpirationDateAttribute($value)
    {
        $this->attributes['training_3_expiration_date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function training_4()
    {
        return $this->belongsTo(RrtTraining::class, 'training_4_id');
    }

    public function getTraining4DateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setTraining4DateAttribute($value)
    {
        $this->attributes['training_4_date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function getTraining4ExpirationDateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setTraining4ExpirationDateAttribute($value)
    {
        $this->attributes['training_4_expiration_date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function getTrainingSupportDocumentsAttribute()
    {
        return $this->getMedia('training_support_documents');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
