<?php

namespace App\Models;

use \DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class RelevantTraining extends Model
{
    use SoftDeletes;
    use HasFactory;

    public $table = 'relevant_trainings';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'experience_in_crec_id',
        'strategic_communications_planning_id',
        'media_environments_id',
        'content_of_media_communications_id',
        'graphic_design_id',
        'social_media_web_content_id',
        'communications_field_deployment_id',
        'audience_analysis_strategies_id',
        'community_engagement_id',
        'specialist_in_health_educ_ches_or_a_certificate_of_master_id',
        'health_education_communication_programme_id',
        'participation_in_crisis_and_emergency_risk_communication_id',
        'crisis_and_emergency_risk_communication_cerc_trainer_id',
        'content_of_the_intervener_hearing_id',
        'stakeholder_organization_id',
        'responsibility_for_response_risk_id',
        'decision_memos_id',
        'user_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function experience_in_crec()
    {
        return $this->belongsTo(TrainingLevel::class, 'experience_in_crec_id');
    }

    public function strategic_communications_planning()
    {
        return $this->belongsTo(TrainingLevel::class, 'strategic_communications_planning_id');
    }

    public function media_environments()
    {
        return $this->belongsTo(TrainingLevel::class, 'media_environments_id');
    }

    public function content_of_media_communications()
    {
        return $this->belongsTo(TrainingLevel::class, 'content_of_media_communications_id');
    }

    public function graphic_design()
    {
        return $this->belongsTo(TrainingLevel::class, 'graphic_design_id');
    }

    public function social_media_web_content()
    {
        return $this->belongsTo(TrainingLevel::class, 'social_media_web_content_id');
    }

    public function communications_field_deployment()
    {
        return $this->belongsTo(TrainingLevel::class, 'communications_field_deployment_id');
    }

    public function audience_analysis_strategies()
    {
        return $this->belongsTo(TrainingLevel::class, 'audience_analysis_strategies_id');
    }

    public function community_engagement()
    {
        return $this->belongsTo(TrainingLevel::class, 'community_engagement_id');
    }

    public function specialist_in_health_educ_ches_or_a_certificate_of_master()
    {
        return $this->belongsTo(TrainingLevel::class, 'specialist_in_health_educ_ches_or_a_certificate_of_master_id');
    }

    public function health_education_communication_programme()
    {
        return $this->belongsTo(TrainingLevel::class, 'health_education_communication_programme_id');
    }

    public function participation_in_crisis_and_emergency_risk_communication()
    {
        return $this->belongsTo(TrainingLevel::class, 'participation_in_crisis_and_emergency_risk_communication_id');
    }

    public function crisis_and_emergency_risk_communication_cerc_trainer()
    {
        return $this->belongsTo(TrainingLevel::class, 'crisis_and_emergency_risk_communication_cerc_trainer_id');
    }

    public function political_experiences()
    {
        return $this->belongsToMany(TrainingLevel::class);
    }

    public function content_of_the_intervener_hearing()
    {
        return $this->belongsTo(TrainingLevel::class, 'content_of_the_intervener_hearing_id');
    }

    public function stakeholder_organization()
    {
        return $this->belongsTo(TrainingLevel::class, 'stakeholder_organization_id');
    }

    public function responsibility_for_response_risk()
    {
        return $this->belongsTo(TrainingLevel::class, 'responsibility_for_response_risk_id');
    }

    public function decision_memos()
    {
        return $this->belongsTo(TrainingLevel::class, 'decision_memos_id');
    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
