<?php

namespace App\Models;

use \DateTimeInterface;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;
use Spatie\MediaLibrary\MediaCollections\Models\Media;

class RequestDatabase extends Model implements HasMedia
{
    use SoftDeletes;
    use InteractsWithMedia;
    use HasFactory;

    public const REQUEST_APPROVAL_RADIO = [
        'Approved'   => 'Approved',
        'Denied'     => 'Denied',
        'In Process' => 'In Process',
    ];

    public $table = 'request_databases';

    protected $dates = [
        'request_date',
        'date_of_request_approval_denial',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'requester_id',
        'request_date',
        'request_approval',
        'date_of_request_approval_denial',
        'request_id',
        'if_other_above_specify',
        'request_location_id',
        'request_duration',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function registerMediaConversions(Media $media = null): void
    {
        $this->addMediaConversion('thumb')->fit('crop', 50, 50);
        $this->addMediaConversion('preview')->fit('crop', 120, 120);
    }

    public function requester()
    {
        return $this->belongsTo(Requester::class, 'requester_id');
    }

    public function getRequestDateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setRequestDateAttribute($value)
    {
        $this->attributes['request_date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function getDateOfRequestApprovalDenialAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setDateOfRequestApprovalDenialAttribute($value)
    {
        $this->attributes['date_of_request_approval_denial'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function request()
    {
        return $this->belongsTo(RequestType::class, 'request_id');
    }

    public function technical_requests()
    {
        return $this->belongsToMany(RrtRole::class);
    }

    public function request_location()
    {
        return $this->belongsTo(Region::class, 'request_location_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
