<?php

namespace App\Models;

use \DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class WaterSanitationHygieneWash extends Model
{
    use SoftDeletes;
    use HasFactory;

    public $table = 'water_sanitation_hygiene_washes';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'in_healthcare_settings_id',
        'in_a_non_medical_id',
        'source_water_assessment_id',
        'water_analysis_id',
        'train_others_on_water_testing_and_aquatab_id',
        'water_infrastructure_mapping_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function in_healthcare_settings()
    {
        return $this->belongsTo(TrainingLevel::class, 'in_healthcare_settings_id');
    }

    public function in_a_non_medical()
    {
        return $this->belongsTo(TrainingLevel::class, 'in_a_non_medical_id');
    }

    public function source_water_assessment()
    {
        return $this->belongsTo(TrainingLevel::class, 'source_water_assessment_id');
    }

    public function water_analysis()
    {
        return $this->belongsTo(TrainingLevel::class, 'water_analysis_id');
    }

    public function train_others_on_water_testing_and_aquatab()
    {
        return $this->belongsTo(TrainingLevel::class, 'train_others_on_water_testing_and_aquatab_id');
    }

    public function water_infrastructure_mapping()
    {
        return $this->belongsTo(TrainingLevel::class, 'water_infrastructure_mapping_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
