@extends('layouts.admin')
@section('content')
<div class="content">

    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default">
                <div class="panel-heading">
                    {{ trans('global.create') }} {{ trans('cruds.deploymentOpportunity.title_singular') }}
                </div>
                <div class="panel-body">
                    <form method="POST" action="{{ route("admin.deployment-opportunities.store") }}" enctype="multipart/form-data">
                        @csrf
                        <div class="form-group {{ $errors->has('name') ? 'has-error' : '' }}">
                            <label class="required" for="name">{{ trans('cruds.deploymentOpportunity.fields.name') }}</label>
                            <input class="form-control" type="text" name="name" id="name" value="{{ old('name', '') }}" required>
                            @if($errors->has('name'))
                                <span class="help-block" role="alert">{{ $errors->first('name') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.deploymentOpportunity.fields.name_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('region') ? 'has-error' : '' }}">
                            <label for="region_id">{{ trans('cruds.deploymentOpportunity.fields.region') }}</label>
                            <select class="form-control select2" name="region_id" id="region_id">
                                @foreach($regions as $id => $entry)
                                    <option value="{{ $id }}" {{ old('region_id') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                                @endforeach
                            </select>
                            @if($errors->has('region'))
                                <span class="help-block" role="alert">{{ $errors->first('region') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.deploymentOpportunity.fields.region_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('posting_number') ? 'has-error' : '' }}">
                            <label for="posting_number">{{ trans('cruds.deploymentOpportunity.fields.posting_number') }}</label>
                            <input class="form-control" type="number" name="posting_number" id="posting_number" value="{{ old('posting_number', '') }}" step="1">
                            @if($errors->has('posting_number'))
                                <span class="help-block" role="alert">{{ $errors->first('posting_number') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.deploymentOpportunity.fields.posting_number_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('logistics_administrator') ? 'has-error' : '' }}">
                            <label for="logistics_administrator_id">{{ trans('cruds.deploymentOpportunity.fields.logistics_administrator') }}</label>
                            <select class="form-control select2" name="logistics_administrator_id" id="logistics_administrator_id">
                                @foreach($logistics_administrators as $id => $entry)
                                    <option value="{{ $id }}" {{ old('logistics_administrator_id') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                                @endforeach
                            </select>
                            @if($errors->has('logistics_administrator'))
                                <span class="help-block" role="alert">{{ $errors->first('logistics_administrator') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.deploymentOpportunity.fields.logistics_administrator_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('event_name') ? 'has-error' : '' }}">
                            <label for="event_name">{{ trans('cruds.deploymentOpportunity.fields.event_name') }}</label>
                            <input class="form-control" type="text" name="event_name" id="event_name" value="{{ old('event_name', '') }}">
                            @if($errors->has('event_name'))
                                <span class="help-block" role="alert">{{ $errors->first('event_name') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.deploymentOpportunity.fields.event_name_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('deployer_position_title') ? 'has-error' : '' }}">
                            <label for="deployer_position_title">{{ trans('cruds.deploymentOpportunity.fields.deployer_position_title') }}</label>
                            <input class="form-control" type="text" name="deployer_position_title" id="deployer_position_title" value="{{ old('deployer_position_title', '') }}">
                            @if($errors->has('deployer_position_title'))
                                <span class="help-block" role="alert">{{ $errors->first('deployer_position_title') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.deploymentOpportunity.fields.deployer_position_title_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('expected_deployment_start_date') ? 'has-error' : '' }}">
                            <label for="expected_deployment_start_date">{{ trans('cruds.deploymentOpportunity.fields.expected_deployment_start_date') }}</label>
                            <input class="form-control date" type="text" name="expected_deployment_start_date" id="expected_deployment_start_date" value="{{ old('expected_deployment_start_date') }}">
                            @if($errors->has('expected_deployment_start_date'))
                                <span class="help-block" role="alert">{{ $errors->first('expected_deployment_start_date') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.deploymentOpportunity.fields.expected_deployment_start_date_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('actual_deployment_start_date') ? 'has-error' : '' }}">
                            <label for="actual_deployment_start_date">{{ trans('cruds.deploymentOpportunity.fields.actual_deployment_start_date') }}</label>
                            <input class="form-control date" type="text" name="actual_deployment_start_date" id="actual_deployment_start_date" value="{{ old('actual_deployment_start_date') }}">
                            @if($errors->has('actual_deployment_start_date'))
                                <span class="help-block" role="alert">{{ $errors->first('actual_deployment_start_date') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.deploymentOpportunity.fields.actual_deployment_start_date_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('expected_deployment_end_date') ? 'has-error' : '' }}">
                            <label for="expected_deployment_end_date">{{ trans('cruds.deploymentOpportunity.fields.expected_deployment_end_date') }}</label>
                            <input class="form-control date" type="text" name="expected_deployment_end_date" id="expected_deployment_end_date" value="{{ old('expected_deployment_end_date') }}">
                            @if($errors->has('expected_deployment_end_date'))
                                <span class="help-block" role="alert">{{ $errors->first('expected_deployment_end_date') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.deploymentOpportunity.fields.expected_deployment_end_date_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('actual_deployment_end_date') ? 'has-error' : '' }}">
                            <label for="actual_deployment_end_date">{{ trans('cruds.deploymentOpportunity.fields.actual_deployment_end_date') }}</label>
                            <input class="form-control date" type="text" name="actual_deployment_end_date" id="actual_deployment_end_date" value="{{ old('actual_deployment_end_date') }}">
                            @if($errors->has('actual_deployment_end_date'))
                                <span class="help-block" role="alert">{{ $errors->first('actual_deployment_end_date') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.deploymentOpportunity.fields.actual_deployment_end_date_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('number_of_deployers') ? 'has-error' : '' }}">
                            <label for="number_of_deployers">{{ trans('cruds.deploymentOpportunity.fields.number_of_deployers') }}</label>
                            <input class="form-control" type="number" name="number_of_deployers" id="number_of_deployers" value="{{ old('number_of_deployers', '') }}" step="1">
                            @if($errors->has('number_of_deployers'))
                                <span class="help-block" role="alert">{{ $errors->first('number_of_deployers') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.deploymentOpportunity.fields.number_of_deployers_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('location_city') ? 'has-error' : '' }}">
                            <label for="location_city">{{ trans('cruds.deploymentOpportunity.fields.location_city') }}</label>
                            <input class="form-control" type="text" name="location_city" id="location_city" value="{{ old('location_city', '') }}">
                            @if($errors->has('location_city'))
                                <span class="help-block" role="alert">{{ $errors->first('location_city') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.deploymentOpportunity.fields.location_city_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('location_province_region') ? 'has-error' : '' }}">
                            <label for="location_province_region_id">{{ trans('cruds.deploymentOpportunity.fields.location_province_region') }}</label>
                            <select class="form-control select2" name="location_province_region_id" id="location_province_region_id">
                                @foreach($location_province_regions as $id => $entry)
                                    <option value="{{ $id }}" {{ old('location_province_region_id') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                                @endforeach
                            </select>
                            @if($errors->has('location_province_region'))
                                <span class="help-block" role="alert">{{ $errors->first('location_province_region') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.deploymentOpportunity.fields.location_province_region_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('language_required') ? 'has-error' : '' }}">
                            <label for="language_required">{{ trans('cruds.deploymentOpportunity.fields.language_required') }}</label>
                            <textarea class="form-control ckeditor" name="language_required" id="language_required">{!! old('language_required') !!}</textarea>
                            @if($errors->has('language_required'))
                                <span class="help-block" role="alert">{{ $errors->first('language_required') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.deploymentOpportunity.fields.language_required_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('request') ? 'has-error' : '' }}">
                            <label for="request_id">{{ trans('cruds.deploymentOpportunity.fields.request') }}</label>
                            <select class="form-control select2" name="request_id" id="request_id">
                                @foreach($requests as $id => $entry)
                                    <option value="{{ $id }}" {{ old('request_id') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                                @endforeach
                            </select>
                            @if($errors->has('request'))
                                <span class="help-block" role="alert">{{ $errors->first('request') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.deploymentOpportunity.fields.request_helper') }}</span>
                        </div>
                        <div class="form-group">
                            <button class="btn btn-danger" type="submit">
                                {{ trans('global.save') }}
                            </button>
                        </div>
                    </form>
                </div>
            </div>



        </div>
    </div>
</div>
@endsection

@section('scripts')
<script>
    $(document).ready(function () {
  function SimpleUploadAdapter(editor) {
    editor.plugins.get('FileRepository').createUploadAdapter = function(loader) {
      return {
        upload: function() {
          return loader.file
            .then(function (file) {
              return new Promise(function(resolve, reject) {
                // Init request
                var xhr = new XMLHttpRequest();
                xhr.open('POST', '{{ route('admin.deployment-opportunities.storeCKEditorImages') }}', true);
                xhr.setRequestHeader('x-csrf-token', window._token);
                xhr.setRequestHeader('Accept', 'application/json');
                xhr.responseType = 'json';

                // Init listeners
                var genericErrorText = `Couldn't upload file: ${ file.name }.`;
                xhr.addEventListener('error', function() { reject(genericErrorText) });
                xhr.addEventListener('abort', function() { reject() });
                xhr.addEventListener('load', function() {
                  var response = xhr.response;

                  if (!response || xhr.status !== 201) {
                    return reject(response && response.message ? `${genericErrorText}\n${xhr.status} ${response.message}` : `${genericErrorText}\n ${xhr.status} ${xhr.statusText}`);
                  }

                  $('form').append('<input type="hidden" name="ck-media[]" value="' + response.id + '">');

                  resolve({ default: response.url });
                });

                if (xhr.upload) {
                  xhr.upload.addEventListener('progress', function(e) {
                    if (e.lengthComputable) {
                      loader.uploadTotal = e.total;
                      loader.uploaded = e.loaded;
                    }
                  });
                }

                // Send request
                var data = new FormData();
                data.append('upload', file);
                data.append('crud_id', '{{ $deploymentOpportunity->id ?? 0 }}');
                xhr.send(data);
              });
            })
        }
      };
    }
  }

  var allEditors = document.querySelectorAll('.ckeditor');
  for (var i = 0; i < allEditors.length; ++i) {
    ClassicEditor.create(
      allEditors[i], {
        extraPlugins: [SimpleUploadAdapter]
      }
    );
  }
});
</script>

@endsection