@extends('layouts.admin')
@section('content')
<div class="content">

    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default">
                <div class="panel-heading">
                    {{ trans('global.create') }} {{ trans('cruds.requestDatabase.title_singular') }}
                </div>
                <div class="panel-body">
                    <form method="POST" action="{{ route("admin.request-databases.store") }}" enctype="multipart/form-data">
                        @csrf
                        <div class="form-group {{ $errors->has('requester') ? 'has-error' : '' }}">
                            <label for="requester_id">{{ trans('cruds.requestDatabase.fields.requester') }}</label>
                            <select class="form-control select2" name="requester_id" id="requester_id">
                                @foreach($requesters as $id => $entry)
                                    <option value="{{ $id }}" {{ old('requester_id') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                                @endforeach
                            </select>
                            @if($errors->has('requester'))
                                <span class="help-block" role="alert">{{ $errors->first('requester') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.requestDatabase.fields.requester_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('request_date') ? 'has-error' : '' }}">
                            <label for="request_date">{{ trans('cruds.requestDatabase.fields.request_date') }}</label>
                            <input class="form-control date" type="text" name="request_date" id="request_date" value="{{ old('request_date') }}">
                            @if($errors->has('request_date'))
                                <span class="help-block" role="alert">{{ $errors->first('request_date') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.requestDatabase.fields.request_date_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('request_approval') ? 'has-error' : '' }}">
                            <label>{{ trans('cruds.requestDatabase.fields.request_approval') }}</label>
                            @foreach(App\Models\RequestDatabase::REQUEST_APPROVAL_RADIO as $key => $label)
                                <div>
                                    <input type="radio" id="request_approval_{{ $key }}" name="request_approval" value="{{ $key }}" {{ old('request_approval', 'In Process') === (string) $key ? 'checked' : '' }}>
                                    <label for="request_approval_{{ $key }}" style="font-weight: 400">{{ $label }}</label>
                                </div>
                            @endforeach
                            @if($errors->has('request_approval'))
                                <span class="help-block" role="alert">{{ $errors->first('request_approval') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.requestDatabase.fields.request_approval_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('date_of_request_approval_denial') ? 'has-error' : '' }}">
                            <label for="date_of_request_approval_denial">{{ trans('cruds.requestDatabase.fields.date_of_request_approval_denial') }}</label>
                            <input class="form-control date" type="text" name="date_of_request_approval_denial" id="date_of_request_approval_denial" value="{{ old('date_of_request_approval_denial') }}">
                            @if($errors->has('date_of_request_approval_denial'))
                                <span class="help-block" role="alert">{{ $errors->first('date_of_request_approval_denial') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.requestDatabase.fields.date_of_request_approval_denial_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('request') ? 'has-error' : '' }}">
                            <label for="request_id">{{ trans('cruds.requestDatabase.fields.request') }}</label>
                            <select class="form-control select2" name="request_id" id="request_id">
                                @foreach($requests as $id => $entry)
                                    <option value="{{ $id }}" {{ old('request_id') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                                @endforeach
                            </select>
                            @if($errors->has('request'))
                                <span class="help-block" role="alert">{{ $errors->first('request') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.requestDatabase.fields.request_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('if_other_above_specify') ? 'has-error' : '' }}">
                            <label for="if_other_above_specify">{{ trans('cruds.requestDatabase.fields.if_other_above_specify') }}</label>
                            <textarea class="form-control ckeditor" name="if_other_above_specify" id="if_other_above_specify">{!! old('if_other_above_specify') !!}</textarea>
                            @if($errors->has('if_other_above_specify'))
                                <span class="help-block" role="alert">{{ $errors->first('if_other_above_specify') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.requestDatabase.fields.if_other_above_specify_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('technical_requests') ? 'has-error' : '' }}">
                            <label for="technical_requests">{{ trans('cruds.requestDatabase.fields.technical_request') }}</label>
                            <div style="padding-bottom: 4px">
                                <span class="btn btn-info btn-xs select-all" style="border-radius: 0">{{ trans('global.select_all') }}</span>
                                <span class="btn btn-info btn-xs deselect-all" style="border-radius: 0">{{ trans('global.deselect_all') }}</span>
                            </div>
                            <select class="form-control select2" name="technical_requests[]" id="technical_requests" multiple>
                                @foreach($technical_requests as $id => $technical_request)
                                    <option value="{{ $id }}" {{ in_array($id, old('technical_requests', [])) ? 'selected' : '' }}>{{ $technical_request }}</option>
                                @endforeach
                            </select>
                            @if($errors->has('technical_requests'))
                                <span class="help-block" role="alert">{{ $errors->first('technical_requests') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.requestDatabase.fields.technical_request_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('request_location') ? 'has-error' : '' }}">
                            <label for="request_location_id">{{ trans('cruds.requestDatabase.fields.request_location') }}</label>
                            <select class="form-control select2" name="request_location_id" id="request_location_id">
                                @foreach($request_locations as $id => $entry)
                                    <option value="{{ $id }}" {{ old('request_location_id') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                                @endforeach
                            </select>
                            @if($errors->has('request_location'))
                                <span class="help-block" role="alert">{{ $errors->first('request_location') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.requestDatabase.fields.request_location_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('request_duration') ? 'has-error' : '' }}">
                            <label for="request_duration">{{ trans('cruds.requestDatabase.fields.request_duration') }}</label>
                            <input class="form-control" type="number" name="request_duration" id="request_duration" value="{{ old('request_duration', '') }}" step="1">
                            @if($errors->has('request_duration'))
                                <span class="help-block" role="alert">{{ $errors->first('request_duration') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.requestDatabase.fields.request_duration_helper') }}</span>
                        </div>
                        <div class="form-group">
                            <button class="btn btn-danger" type="submit">
                                {{ trans('global.save') }}
                            </button>
                        </div>
                    </form>
                </div>
            </div>



        </div>
    </div>
</div>
@endsection

@section('scripts')
<script>
    $(document).ready(function () {
  function SimpleUploadAdapter(editor) {
    editor.plugins.get('FileRepository').createUploadAdapter = function(loader) {
      return {
        upload: function() {
          return loader.file
            .then(function (file) {
              return new Promise(function(resolve, reject) {
                // Init request
                var xhr = new XMLHttpRequest();
                xhr.open('POST', '{{ route('admin.request-databases.storeCKEditorImages') }}', true);
                xhr.setRequestHeader('x-csrf-token', window._token);
                xhr.setRequestHeader('Accept', 'application/json');
                xhr.responseType = 'json';

                // Init listeners
                var genericErrorText = `Couldn't upload file: ${ file.name }.`;
                xhr.addEventListener('error', function() { reject(genericErrorText) });
                xhr.addEventListener('abort', function() { reject() });
                xhr.addEventListener('load', function() {
                  var response = xhr.response;

                  if (!response || xhr.status !== 201) {
                    return reject(response && response.message ? `${genericErrorText}\n${xhr.status} ${response.message}` : `${genericErrorText}\n ${xhr.status} ${xhr.statusText}`);
                  }

                  $('form').append('<input type="hidden" name="ck-media[]" value="' + response.id + '">');

                  resolve({ default: response.url });
                });

                if (xhr.upload) {
                  xhr.upload.addEventListener('progress', function(e) {
                    if (e.lengthComputable) {
                      loader.uploadTotal = e.total;
                      loader.uploaded = e.loaded;
                    }
                  });
                }

                // Send request
                var data = new FormData();
                data.append('upload', file);
                data.append('crud_id', '{{ $requestDatabase->id ?? 0 }}');
                xhr.send(data);
              });
            })
        }
      };
    }
  }

  var allEditors = document.querySelectorAll('.ckeditor');
  for (var i = 0; i < allEditors.length; ++i) {
    ClassicEditor.create(
      allEditors[i], {
        extraPlugins: [SimpleUploadAdapter]
      }
    );
  }
});
</script>

@endsection